import * as React from 'react'
import {
  AppBar,
  Toolbar,
  Typography,
  CssBaseline,
  Container,
  Box,
  Grid,
  Card,
  CardContent,
  CardMedia,
  Button,
  Grow,
  IconButton,
} from '@mui/material'
import { createTheme, ThemeProvider } from '@mui/material/styles'
import { useNavigate } from 'react-router-dom'
import VideoCallIcon from '@mui/icons-material/VideoCall'
import SchoolIcon from '@mui/icons-material/School'
import FacebookIcon from '@mui/icons-material/Facebook'
import YouTubeIcon from '@mui/icons-material/YouTube'
import BackgroundImage from '../../Assests/Images/Background.jpeg'

const defaultTheme = createTheme({
  palette: {
    primary: {
      main: '#1976d2',
    },
    secondary: {
      main: '#dc004e',
    },
  },
  typography: {
    fontFamily: 'Roboto, sans-serif',
  },
})

// function Header() {
//   return (
//     <AppBar position='static' sx={{ backgroundColor: 'primary.main' }}>
//       <Toolbar>
//         <Typography
//           variant='h4'
//           component='div'
//           sx={{ flexGrow: 1, fontFamily: 'Roboto', fontWeight: 'bold' }}
//         >
//           SPEAKEZY
//         </Typography>
//         <IconButton color='inherit' href='#'>
//           <VideoCallIcon />
//         </IconButton>
//         <IconButton color='inherit' href='#'>
//           <SchoolIcon />
//         </IconButton>
//       </Toolbar>
//     </AppBar>
//   )
// }

function Footer() {
  return (
    <Box
      sx={{
        bgcolor: 'transparent',
        background: 'rgba(25, 118, 210, 0.8)',
        p: 6,
        color: 'white',
      }}
      component='footer'
    >
      <Container maxWidth='lg'>
        <Grid container spacing={4} justifyContent='space-between'>
          <Grid item xs={12} sm={4}>
            <Typography
              variant='h6'
              gutterBottom
              sx={{
                transition: 'color 0.3s ease, transform 0.3s ease',
                '&:hover': {
                  color: '#ffeb3b',
                  transform: 'scale(1.05)',
                },
              }}
            >
              About Us
            </Typography>
            <Typography
              variant='subtitle1'
              sx={{
                transition: 'color 0.3s ease, transform 0.3s ease',
                '&:hover': {
                  color: '#ffeb3b',
                  transform: 'scale(1.05)',
                },
              }}
            >
              Learn more about our mission to enhance digital accessibility and inclusivity.
            </Typography>
          </Grid>
          <Grid item xs={12} sm={4}>
            <Typography
              variant='h6'
              gutterBottom
              sx={{
                transition: 'color 0.3s ease, transform 0.3s ease',
                '&:hover': {
                  color: '#ffeb3b',
                  transform: 'scale(1.05)',
                },
              }}
            >
              Contact
            </Typography>
            <Typography
              variant='subtitle1'
              sx={{
                transition: 'color 0.3s ease, transform 0.3s ease',
                '&:hover': {
                  color: '#ffeb3b',
                  transform: 'scale(1.05)',
                },
              }}
            >
              Email: contact@speakezy.com
            </Typography>
          </Grid>
          <Grid item xs={12} sm={4}>
            <Typography
              variant='h6'
              gutterBottom
              sx={{
                transition: 'color 0.3s ease, transform 0.3s ease',
                '&:hover': {
                  color: '#ffeb3b',
                  transform: 'scale(1.05)',
                },
              }}
            >
              Follow Us
            </Typography>
            <Box sx={{ display: 'flex', justifyContent: 'center' }}>
              <IconButton
                color='inherit'
                href='https://www.facebook.com'
                sx={{
                  transition: 'transform 0.3s ease',
                  '&:hover': {
                    color: '#3b5998',
                    transform: 'scale(1.2)',
                  },
                }}
              >
                <FacebookIcon fontSize='large' />
              </IconButton>
              <IconButton
                color='inherit'
                href='https://www.youtube.com'
                sx={{
                  transition: 'transform 0.3s ease',
                  '&:hover': {
                    color: '#FF0000',
                    transform: 'scale(1.2)',
                  },
                }}
              >
                <YouTubeIcon fontSize='large' />
              </IconButton>
            </Box>
          </Grid>
        </Grid>
        <Typography
          variant='body2'
          align='center'
          sx={{
            mt: 4,
            transition: 'color 0.3s ease, transform 0.3s ease',
            '&:hover': { color: '#ffeb3b', transform: 'scale(1.05)' },
          }}
        >
          {'© '}
          {new Date().getFullYear()} {'SPEAKEZY. All rights reserved.'}
        </Typography>
      </Container>
    </Box>
  )
}

export default function HomePage() {
  const navigate = useNavigate()

  const handleVideoCallClick = () => {
    navigate('/videocall')
  }

  const handleTrainingClick = () => {
    navigate('/training')
  }

  return (
    <ThemeProvider theme={defaultTheme}>
      <CssBaseline />
      <Box
        sx={{
          backgroundImage: `url(${BackgroundImage})`,
          backgroundRepeat: 'no-repeat',
          backgroundSize: 'cover',
          backgroundPosition: 'center',
          minHeight: '100vh',
          display: 'flex',
          flexDirection: 'column',
          justifyContent: 'center',
          alignItems: 'center',
          padding: 2,
          mb: 0, // Remove margin at the bottom to eliminate gap
        }}
      >
        <Container component='main' maxWidth='lg' sx={{ textAlign: 'center' }}>
          <Typography
            variant='h2'
            component='h1'
            sx={{
              color: 'white',
              fontWeight: 'bold',
              mb: 4,
              textShadow: '2px 2px 4px rgba(0, 0, 0, 0.5)',
            }}
          >
            Welcome to SPEAKEZY
          </Typography>
          <Grid container spacing={4} justifyContent='center'>
            <Grow in={true} timeout={1000}>
              <Grid item xs={12} sm={6} md={4}>
                <Card
                  elevation={8}
                  sx={{
                    transition: 'transform 0.3s ease',
                    '&:hover': { transform: 'scale(1.05)' },
                  }}
                >
                  <CardMedia>
                    <Box
                      sx={{
                        display: 'flex',
                        justifyContent: 'center',
                        alignItems: 'center',
                        height: 200,
                        backgroundColor: 'primary.light',
                      }}
                    >
                      <VideoCallIcon sx={{ fontSize: 100, color: 'white' }} />
                    </Box>
                  </CardMedia>
                  <CardContent sx={{ textAlign: 'center' }}>
                    <Typography variant='h5' component='h2' sx={{ fontWeight: 'bold' }}>
                      Colloborate with Community
                    </Typography>
                    <Button
                      variant='contained'
                      color='primary'
                      sx={{ mt: 2 }}
                      onClick={handleVideoCallClick}
                    >
                      Start Video Call
                    </Button>
                  </CardContent>
                </Card>
              </Grid>
            </Grow>
            <Grow in={true} timeout={1500}>
              <Grid item xs={12} sm={6} md={4}>
                <Card
                  elevation={8}
                  sx={{
                    transition: 'transform 0.3s ease',
                    '&:hover': { transform: 'scale(1.05)' },
                  }}
                >
                  <CardMedia>
                    <Box
                      sx={{
                        display: 'flex',
                        justifyContent: 'center',
                        alignItems: 'center',
                        height: 200,
                        backgroundColor: 'secondary.light',
                      }}
                    >
                      <SchoolIcon sx={{ fontSize: 100, color: 'white' }} />
                    </Box>
                  </CardMedia>
                  <CardContent sx={{ textAlign: 'center' }}>
                    <Typography variant='h5' component='h2' sx={{ fontWeight: 'bold' }}>
                      Train Sign Language
                    </Typography>
                    <Button
                      variant='contained'
                      color='secondary'
                      sx={{ mt: 2 }}
                      onClick={handleTrainingClick}
                    >
                      Start Training
                    </Button>
                  </CardContent>
                </Card>
              </Grid>
            </Grow>
          </Grid>
        </Container>
      </Box>
      <Footer />
    </ThemeProvider>
  )
}
